@@ -1,16 +1,16 @@
 ######################################################################
 # urlhack.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: urlhack.inc.pl,v 1.107 2011/05/04 07:26:50 papu Exp $
+# $Id: urlhack.inc.pl,v 1.437 2012/01/31 10:11:55 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-rc6 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -23,31 +23,28 @@
 # SEOкURLϥåץ饰
 #
 ######################################################################
-
 # PATH_INFO Ȥ0ξFile not found­)
 $urlhack::use_path_info=1
 	if(!defined($urlhack::use_path_info));
-
+#
 # fake extension ĥҵ
 $urlhack::fake_extention="/"
 	if(!defined($urlhack::fake_extention));
-
-# use puny url 0:16ʥ󥳡 1:puny󥳡
+#
+# use puny url 0:16ʥ󥳡 1:puny󥳡 2:UTF8󥳡
 $urlhack::use_puny=1
 	if(!defined($urlhack::use_puny));
-
+#
 # not convert Alphabet or Number ( or dot and slash) page
 $urlhack::noconvert_marks=2
 	if(!defined($urlhack::noconvert_marks));
-
+#
 # force url hack (non extention .cgi)
 $urlhack::force_exec=0
 	if(!defined($urlhack::force_exec));
-
+#
+######################################################################
 use strict;
-
-# Initlize
-
 sub plugin_urlhack_init {
 	&exec_explugin_sub("lang");
 	unless($::form{mypage} eq '' || $::form{mypage} eq $::FrontPage) {
@@ -65,14 +62,11 @@ sub plugin_urlhack_init {
 			, 'make_cookedurl'=>\&make_cookedurl);
 	}
 }
-
 sub plugin_urlhack_init_path_info {
 	my $req=$ENV{PATH_INFO};
-
 	unless($::form{cmd} eq '' || $::form{cmd} eq 'read') {
 		return 0;
 	}
-
 	if($urlhack::fake_extention ne '') {
 		my $regex=$urlhack::fake_extention;
 		$regex=~s/([\.\/])/'\\x' . unpack('H2', $1)/eg;
@@ -83,10 +77,8 @@ sub plugin_urlhack_init_path_info {
 		$::form{mypage}=$req;
 		return 0;
 	}
-
 	$req=~s!^/!!g;
 	$req=~s!/$!!g;
-
 	if($urlhack::fake_extention ne '') {
 		my $regex=$urlhack::fake_extention;
 		$regex=~s/([\.\/])/'\\x' . unpack('H2', $1)/eg;
@@ -118,7 +110,6 @@ sub plugin_urlhack_init_path_info {
 	}
 	return 0;
 }
-
 sub plugin_urlhack_init_notfound {
 	if($urlhack::force_exec eq 0) {
 		unless($ENV{SCRIPT_NAME}=~/nph-/ || $ENV{REQUEST_URI}=~/\.cgi/) {
@@ -127,7 +118,6 @@ sub plugin_urlhack_init_notfound {
 		}
 	}
 	my $req;
-
 	if($::form{cmd} eq 'servererror') {
 		if($ENV{REDIRECT_STATUS} eq 404) {
 			$req=$ENV{REDIRECT_URL};
@@ -135,19 +125,15 @@ sub plugin_urlhack_init_notfound {
 			return 0;
 		}
 	}
-
 	if($req ne '' || $::form{cmd} eq '' || $::form{cmd} eq 'read') {
 		$req=$ENV{REQUEST_URI};
 		$req="$req/" if($urlhack::force_exec eq 1 && ($ENV{REQUEST_URI}!~/\.cgi$/ || $ENV{REQUEST_URI}=~/\/$/));
 	} else {
 		return 0;
 	}
-
 	$req=~s/\?.*//g;
-
 	if($urlhack::noconvert_marks eq 2) {
 		my $uri;
-
 		if($req ne '') {
 			if($req eq $ENV{SCRIPT_NAME}) {
 				$uri= $ENV{'SCRIPT_NAME'};
@@ -174,7 +160,6 @@ sub plugin_urlhack_init_notfound {
 	}
 	$req=~s!^/!!g;
 	$req=~s!/$!!g;
-
 	if($urlhack::fake_extention ne '') {
 		my $regex=$urlhack::fake_extention;
 		$regex=~s/([\.\/])/'\\x' . unpack('H2', $1)/eg;
@@ -187,7 +172,6 @@ sub plugin_urlhack_init_notfound {
 		return 0;
 	}
 	$req=&plugin_urlhack_decode($req);
-
 	if($req eq '') {
 		$req=&decode($ENV{QUERY_STRING});
 		if(&is_exist_page($req)) {
@@ -213,8 +197,6 @@ sub plugin_urlhack_init_notfound {
 		return 0;
 	}
 }
-
-
 sub make_cookedurl {
 	my($cookedchunk)=@_;
 	if($urlhack::force_exec eq 0 && $urlhack::use_path_info eq 0) {
@@ -239,41 +221,65 @@ sub make_cookedurl {
 		return "$script/$cookedchunk$urlhack::fake_extention";
 	}
 }
-
 sub plugin_urlhack_decode {
 	my($str)=@_;
 	if($str=~/xn\-/) {
 		&plugin_urlhack_usepuny;
 		$str=~s/\_/\//g;
 		$str=IDNA::Punycode::decode_punycode($str);
-		$str=&code_convert(\$str, 'euc', 'utf8');
-	} else {
+		$str=&code_convert(\$str, $::defaultcode, 'utf8');
+		if($urlhack::use_puny ne 1) {
+			&getbasehref;
+			$::IN_HEAD.=<<EOM;
+<link rel="canonical" href="$::basehref@{[&plugin_urlhack_encode($str,$urlhack::use_puny)]}" />
+EOM
+		}
+	} elsif($str=~/^[0-9A-Fa-f]+/) {
 		$str=~s/([A-Fa-f0-9][A-Fa-f0-9])/pack("C", hex($1))/eg;
-	}
+		if($urlhack::use_puny ne 0) {
+			&getbasehref;
+			$::IN_HEAD.=<<EOM;
+<link rel="canonical" href="$::basehref@{[&plugin_urlhack_encode($str,$urlhack::use_puny)]}" />
+EOM
+		}
+	} else {
+		my $tmp=&decode($str);
+		$str=&code_convert(\$tmp, $::defaultcode, 'utf8');
+		if($urlhack::use_puny ne 2) {
+			&getbasehref;
+			$::IN_HEAD.=<<EOM;
+<link rel="canonical" href="$::basehref@{[&plugin_urlhack_encode($str,$urlhack::use_puny)]}" />
+EOM
+		}
+}
 	$str=~s/\+/\ /g;
 	$str=~s/\!2b/\+/g;
 	return $str;
 }
-
 sub plugin_urlhack_encode {
-	my($str)=@_;
-	if($urlhack::use_puny eq 0) {
+	my($str, $enc)=@_;
+	$enc=$enc eq '' ? $urlhack::use_puny : $enc;
+	if($enc eq 0) {
 		$str=~ s/(.)/unpack('H2', $1)/eg;
+	} elsif($enc eq 2) {
+		$str=&encode(&code_convert(\$str, 'utf8', $::defaultcode));
+		$str=~s!%2d!-!g;
+		$str=~s!%2[Ff]!/!g;
 	} else {
 		&plugin_urlhack_usepuny;
 		$str=~s/\+/!2b/g;
 		$str=~s/\ /+/g;
 		my $org=$str;
-		$str=&code_convert(\$str, 'utf8', 'euc');
+		$str=&code_convert(\$str, 'utf8', $::defaultcode);
 		utf8::decode($str);
 		$str=IDNA::Punycode::encode_punycode($str);
 		$str=~s/\-{3,9}/--/g;
 		$str=~s/\//\_/g if($str ne $org);
 		utf8::encode($str);
+		$str=~s!%2d!-!g;
 	}
 	return $str;
 }
-
 sub plugin_urlhack_usepuny {
 	if($::puny_loaded+0 ne 1) {
 		if($] < 5.008001) {
@@ -284,7 +290,6 @@ sub plugin_urlhack_usepuny {
 	}
 	IDNA::Punycode::idn_prefix('xn--');
 }
-
 1;
 __DATA__
 	return(
@@ -299,7 +304,6 @@ __DATA__
 		'$::urlhack_use_path_info=Method:1=PATH_INFO,0=Not Found Error/' .
 		'$::urlhack_fake_extention=Fake extention:=none,.html,/' .
 		'$::urlhack_noconvert_marks=Not convert charactors:0=All encode,1=Alphabet and number of page name,2=Alphabet and number and dot and slash',
-	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/urlhack/'
+	'url'=>'http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/ExPlugin/urlhack/'
 	);
 __END__
-
