@@ -1,30 +1,27 @@
 ######################################################################
 # admin.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: admin.inc.pl,v 1.40 2010/12/29 06:21:06 papu Exp $
+# $Id: admin.inc.pl,v 1.384 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p1 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
-$admin::ignore_plugin=q{^edit|^admin\.|^newpage|^attach};
-
+$admin::ignore_plugin=q{^edit|^admin\.|^newpage|^attach|^diff|^backup};
 sub plugin_admin_action {
 	my $body;
 	%::auth=&authadminpassword(submit);
 	return('msg'=>"\t$::resource{adminbutton}",'body'=>$auth{html})
 		if($auth{authed} eq 0);
-
 	my @adminlist=();
 	my @dir=();
 	opendir(DIR,"$::plugin_dir");
@@ -50,7 +47,6 @@ sub plugin_admin_action {
 			}
 		}
 	}
-
 	foreach my $plugin(@adminlist) {
 		open(R, "$::plugin_dir/$plugin.inc.pl");
 		my $res=$plugin;
@@ -79,4 +75,3 @@ EOM
 }
 1;
 __END__
-
