@@ -1,29 +1,30 @@
 ######################################################################
 # back.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: back.inc.pl,v 1.38 2011/02/22 20:59:12 papu Exp $
+# $Id: back.inc.pl,v 1.429 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p3 $$
+# "PyukiWiki" version 0.2.0-p2 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 $back::allowpagelink=0
 	if(!defined($back::allowpagelink));
 $back::allowjavascript=1
 	if(!defined($back::allowjavascript));
-
+$back::blacket=1
+	if(!defined($back::blacket));
+######################################################################
 use strict;
-
+$::back::count;
 sub plugin_back_convert {
 	my($str,$align,$hr,$link)=split(/,/,shift);
 	my $body;
@@ -41,18 +42,25 @@ sub plugin_back_convert {
 	}
 	if($link eq "") {
 		if($back::allowjavascript eq 1) {
+			$::back::count+=0;
+			$::back::count++;
 			$body=<<EOM;
-<script type="text/javascript">@{[!$::is_xhtml ? "<!--\n" : '']}
-if(history.length != 0) {
-	document.write('$hr<div align="$align"><a href="javascript:history.go(-1)" title="$str">$str</a></div>');
-}
-@{[!$::is_xhtml ? '//-->' : '']}</script>
+<span id="back_$::back::count"></span>
+<script type="text/javascript"><!--
+if(history.length!=0){d.getElementById("back_$::back::count").innerHTML='$hr<div align="$align">@{[$back::blacket eq 1 ? '[' : '']}<a href="javascript:history.go(-1)" title="$str">$str</a>@{[$back::blacket eq 1 ? ']' : '']}</div>';}
+//--></script>
+<noscript>
+$hr
+<div align="$align">
+@{[$back::blacket eq 1 ? '[' : '']}<a href="$ENV{HTTP_REFERER}" title="$str">$str</a>@{[$back::blacket eq 1 ? ']' : '']}
+</div>
+</noscript>
 EOM
 		} elsif($ENV{HTTP_REFERER} ne '') {
 			$body=<<EOM;
 $hr
 <div align="$align">
-<a href="$ENV{HTTP_REFERER}" title="$str">$str</a>
+@{[$back::blacket eq 1 ? '[' : '']}<a href="$ENV{HTTP_REFERER}" title="$str">$str</a>@{[$back::blacket eq 1 ? ']' : '']}
 </div>
 EOM
 		} else {
@@ -70,4 +78,3 @@ EOM
 }
 1;
 __END__
-
