@@ -1,33 +1,30 @@
 ######################################################################
 # help.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: help.inc.pl,v 1.49 2011/05/04 07:26:50 papu Exp $
+# $Id: help.inc.pl,v 1.462 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=Shift-JIS 1TAB=4Spaces
 ######################################################################
-
 sub plugin_help_action {
 	$::form{mypage}=$::resource{help};
 	if(!&is_readable($::form{mypage})) {
 		&print_error($::resource{auth_readfobidden});
 	}
-
 	&plugin_help_skinex($::form{mypage}, &text_to_html($::database{$::form{mypage}}, mypage=>$::form{mypage}), 2, @_);
 	&close_db;
 	exit;
 }
-
 sub plugin_help_skinex {
 	my ($page, $body, $is_page, $pageplugin) = @_;
 	my $bodyclass = "normal";
@@ -35,7 +32,6 @@ sub plugin_help_skinex {
 	my $admineditable = 0;
 	$pageplugin+=0;
 	$::pageplugin+=0;
-
 	if (&is_frozen($::form{refer}) && &is_exist_page($::form{refer})) {
 		$admineditable = 1;
 		$bodyclass = "frozen";
@@ -44,19 +40,19 @@ sub plugin_help_skinex {
 		$editable = 1;
 	}
 	&makenavigator($page,$is_page,$editable,$admineditable);
-
-	$::IN_HEAD=&meta_robots($::form{cmd},$page,$body) . $::IN_HEAD;
-	$::HTTP_HEADER=&http_header("Content-type: text/html; charset=$::charset", $::HTTP_HEADER);
+	$::IN_HEAD.=&meta_robots($::form{cmd},$page,$body);
+	my $output_mime = $::htmlmode eq "xhtml11"
+		&& $ENV{'HTTP_ACCEPT'}=~ m!application/xhtml\+xml!
+		&& &is_no_xhtml(1) eq 0
+		? 'application/xhtml+xml' : 'text/html';
+	$::HTTP_HEADER=&http_header("Content-type: $output_mime; charset=$::charset", $::HTTP_HEADER);
 	require $::skin_file;
 	my $body=&skin($page, $body, $is_page, $bodyclass, $editable, $admineditable, $::basehref);
 	$body=&_db($body);
-
 	if($::lang eq 'ja' && $::defaultcode ne $::kanjicode) {
 		$body=&code_convert(\$body,   $::kanjicode);
 	}
 	&content_output($::HTTP_HEADER, $body);
 }
-
 1;
 __END__
-
