@@ -1,16 +1,16 @@
 ######################################################################
 # lang.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: lang.inc.pl,v 1.46 2011/01/25 03:11:15 papu Exp $
+# $Id: lang.inc.pl,v 1.438 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p2 $$
+# "PyukiWiki" version 0.2.0-p2 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -19,11 +19,11 @@
 # cookieѥץ饰
 # ExPlugin lang.inc.cgi$::write_location=1ͭˤɬפޤ
 ######################################################################
-
 sub plugin_lang_action {
 	my $body;
 	return if($::lang_cookie eq '' || $::write_location eq 0);
-
+# 0.1.9 fix
+	return if($::useExPlugin eq 1 && $::_exec_plugined{lang} ne 2);
 	my @http_headers=();
 	push(@http_headers, "Status: 302");
 	if($::form{refer} ne '') {
@@ -41,7 +41,5 @@ sub plugin_lang_action {
 	close(STDOUT);
 	exit;
 }
-
 1;
 __END__
-
