@@ -1,42 +1,35 @@
 ######################################################################
 # now.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: now.inc.pl,v 1.33 2007/07/15 07:40:09 papu Exp $
+# $Id: now.inc.pl,v 1.398 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# "PyukiWiki" version 0.2.0-p1 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 use strict;
-use Time::Local;
-
 sub plugin_now_convert {
 	return &plugin_now_inline(@_);
 }
-
 sub plugin_now_inline {
 	my ($format,$now) = split(/,/, shift);
 	my ($y,$m,$d);
 	my ($h,$m,$s);
-
 	$format=&htmlspecialchars($format);
 	$now=&htmlspecialchars($now);
-
 	if($format eq '') {
 		return &date($::now_format);
 	}
 	$now=time if($now eq '');
-
 	if($now=~/ /) {
 		my($date,$time)=split(/ /,$now);
 		if($date=~/-/) {
@@ -53,7 +46,5 @@ sub plugin_now_inline {
 	}
 	return &date($format,$now);
 }
-
 1;
 __END__
-
