@@ -1,27 +1,24 @@
 ######################################################################
 # perlpod.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: perlpod.inc.pl,v 1.84 2011/02/22 20:59:12 papu Exp $
+# $Id: perlpod.inc.pl,v 1.424 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p3 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 use Nana::Pod2Wiki;
 use strict;
-
 require "$::plugin_dir/contents.inc.pl";
-
 sub plugin_perlpod_action {
 	my $file;
 	$file=$::form{file};
@@ -31,7 +28,6 @@ sub plugin_perlpod_action {
 						, $::form{notitle} ne '' ? "notitle" : ""
 						, $::form{source} ne '' ? 1 : 0));
 }
-
 sub plugin_perlpod_convert {
 	my $file;
 	my($file,$notitle,$source)=split(/,/,shift);
@@ -39,7 +35,6 @@ sub plugin_perlpod_convert {
 	return if($file=~/\.\./ || $file=~/^\// || $file=~/[|><%'"]/);
 	return(&perlpod($file,$notitle ne '' ? "notitle" : "",$source));
 }
-
 sub getperlpath{
 	my $perlpath;
 	if(open(R,"$0")) {
@@ -53,14 +48,12 @@ sub getperlpath{
 	}
 	return '';
 }
-
 sub perlpod {
 	my($file,$notitle,$source)=@_;
 	$file=~s/.*\///g;
 	my $dir;
 	$::interwiki_definition="";
 	$::interwiki_definition2="";
-
 	foreach my $dirs($::data_home, $::data_pub, $::explugin_dir, $::plugin_dir
 			, $::res_dir, $::skin_dir, $::image_dir) {
 		if(-r "$dir/$file") {
@@ -76,20 +69,19 @@ sub perlpod {
 	}
 	return("File nod found:$file");
 }
-
 my $level=0;
-
 sub perlpod_sub {
 	my($file,$notitle,$source)=@_;
 	my ($name,$body)=Nana::Pod2Wiki::pod2wiki($file,$notitle);
 	my $html;
+	my $query=&htmlspecialchars($ENV{QUERY_STRING});
 	if($source+0 eq 0) {
 		if($notitle eq '') {
 			$html=&text_to_html("*$name\n\pod2wikidummycontents\n----\n$body");
-			my $contents=&plugin_contents_main("*$ENV{QUERY_STRING}",split(/\n/,"*$name\n\pod2wikidummycontents\n----\n$body"));
+			my $contents=&plugin_contents_main("?$query",split(/\n/,"*$name\n\pod2wikidummycontents\n----\n$body"));
 			$html=~s!pod2wikidummycontents!$contents!g;
 		} else {
-			$html.=&plugin_contents_main("?$ENV{QUERY_STRING}",split(/\n/,"$body"));
+			$html.=&plugin_contents_main("?$query",split(/\n/,"$body"));
 			$html.=&text_to_html("----\n$body");
 		}
 	} else {
@@ -110,14 +102,11 @@ EOM
 	$html=~s/\x4/\:/g;
 	return $html;
 }
-
 sub perlpod_sub2 {
 	my($dir,$file)=@_;
-
 	opendir(DIR,$dir);
 	my @files=readdir(DIR);
 	closedir(DIR);
-
 	foreach(@files) {
 		next if($_ eq '.' || $_ eq '..');
 		my $path="$dir/$_";
@@ -132,8 +121,5 @@ sub perlpod_sub2 {
 	}
 	return "";
 }
-
-
 1;
 __END__
-
