@@ -1,16 +1,16 @@
 ######################################################################
 # rename.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: rename.inc.pl,v 1.81 2011/03/02 03:05:47 papu Exp $
+# $Id: rename.inc.pl,v 1.501 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p4 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Junichi http://www.re-birth.com/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -23,49 +23,34 @@
 #   ǧڥƥλѤѹ
 # Locationإåνˡѹ
 ######################################################################
-
 use constant PLUGIN_RENAME_LOGPAGE => ':RenameLog';
-
-# %_rename_messages is deleted, moved to ./resource/rename.??.txt
-# by nanami
-
 sub plugin_rename_action {
-
 	%::auth=&authadminpassword(submit);
 	return('msg'=>"\t$::resource{rename_plugin_msg_title}",'body'=>$auth{html})
 		if($auth{authed} eq 0);
-
 	$method = &plugin_rename_getvar('method');
 	if ($method eq 'regex') {
 		my $src = &plugin_rename_getvar('src');
 		if ($src eq '') {
 			 return &plugin_rename_phase1();
 		}
-
 		$src_pattern = $src;
 		$src_pattern=~s/\//\\\//g;
 		my @arr0 = grep(/^$src_pattern/, sort keys %::database);
-
 		if(@arr0 == 0){
 			return &plugin_rename_phase1('nomatch');
 		}
-
 		my $dst = &plugin_rename_getvar('dst');
-
 		my @arr1 = map {my $val = $_;$val=~s/$src_pattern/$dst/;$val} @arr0;
-
 		foreach $page (@arr1) {
 			if (! &is_pagename($page)) {
 				return &plugin_rename_phase1('notvalid');
 			}
 		}
-
 		return &plugin_rename_regex(\@arr0, \@arr1);
 	} else {
-
 		$page  = &plugin_rename_getvar('page');
 		$refer = &plugin_rename_getvar('refer');
-
 		if ($refer eq '') {
 			return &plugin_rename_phase1();
 		} elsif (! &is_exist_page($refer)) {
@@ -81,24 +66,16 @@ sub plugin_rename_action {
 		}
 	}
 }
-
-
-#  ѿ
 sub plugin_rename_getvar {
 	my ($key) = @_;
-
 	return $::form{$key};
 	return isset($vars[$key]) ? $vars[$key] : '';
 }
-
-#  顼å
 sub plugin_rename_err {
 	my ($err,$page) = @_;
-
 	if ($err eq '') {
 		return '';
 	}
-
 	$body = $::resource{'rename_plugin_err_' . $err};
 	if (ref($page) eq 'ARRAY') {
 		$page = join(", ", @$page);
@@ -106,19 +83,14 @@ sub plugin_rename_err {
 	if ($page ne ''){
 		 $body = sprintf($body, &htmlspecialchars($page));
 	}
-
 	$msg = sprintf($::resource{'rename_plugin_err'}, $body);
 	return $msg;
 }
-
-# ʳ:ڡ̾ޤɽ
 sub plugin_rename_phase1 {
 	my ($err, $page) = @_;
-
 	$msg    = &plugin_rename_err($err, $page);
 	$refer  = &plugin_rename_getvar('refer');
 	$method = &plugin_rename_getvar('method');
-
 	$radio_regex = $radio_page = '';
 	if ($method eq 'regex') {
 		$radio_regex = ' checked="checked"';
@@ -126,10 +98,8 @@ sub plugin_rename_phase1 {
 		$radio_page  = ' checked="checked"';
 	}
 	$select_refer = &plugin_rename_getselecttag($refer);
-
 	$s_src = htmlspecialchars(&plugin_rename_getvar('src'));
 	$s_dst = htmlspecialchars(&plugin_rename_getvar('dst'));
-
 	%ret = ();
 	$ret{'msg'}  = "\t$::resource{'rename_plugin_msg_title'}";
 	$ret{'body'} = <<EOD;
@@ -150,33 +120,25 @@ $msg
  </div>
 </form>
 EOD
-
 	return %ret;
 }
-
-# ʳ:̾
 sub plugin_rename_phase2 {
 	my $err = shift;
-
 	$msg   = &plugin_rename_err($err);
 	$page  = &plugin_rename_getvar('page');
 	$refer = &plugin_rename_getvar('refer');
-
 	if ($page eq '') {
 		$page = $refer;
 	}
-
 	$msg_related = '';
 	@related = &plugin_rename_getrelated($refer);
 	if (@related > 0) {
 		$msg_related = $::resource{'rename_plugin_msg_do_related'} .
 			'<input type="checkbox" name="related" value="1" checked="checked" /><br />';
 	}
-
 	$msg_rename = sprintf($::resource{'rename_plugin_msg_rename'}, &make_pagelink($refer));
 	$s_page  = &htmlspecialchars($page);
 	$s_refer = &htmlspecialchars($refer);
-
 	%ret = ();
 	$ret{'msg'}  = "\t$::resource{'rename_plugin_msg_title'}";
 	$ret{'body'} = <<EOD;
@@ -193,7 +155,6 @@ $msg
  </div>
 </form>
 EOD
-
 	if (@related > 0) {
 		$ret{'body'} .= '<hr /><p>' . $::resource{'rename_plugin_msg_related'} . '</p><ul>';
 		foreach $name (sort @related) {
@@ -201,45 +162,32 @@ EOD
 		}
 		$ret{'body'} .= '</ul>';
 	}
-
 	return %ret;
 }
-
-# ڡ̾ȴϢڡ󤷡phase3
 sub plugin_rename_refer {
 	$page  = &plugin_rename_getvar('page');
 	$refer = &plugin_rename_getvar('refer');
-
 	my %pages = ();
 	$pages{&dbmname($refer)} = &dbmname($page);
-
 	if (&plugin_rename_getvar('related') ne '') {
 		$from = &strip_bracket($refer);
 		$to   = &strip_bracket($page);
-
 		foreach $_page (&plugin_rename_getrelated($refer)) {
-
 			($_page_to = $_page)=~s/$from/$to/;
 			$pages{&dbmname($_page)} = &dbmname($_page_to);
 		}
 	}
-
 	return &plugin_rename_phase3(%pages);
 }
-
-# ɽǥڡִ
 sub plugin_rename_regex {
 	my ($arr_from, $arr_to) = @_;
-
 	@exists = ();
 	foreach my $page (@$arr_to) {
 		if (&is_exist_page($page)) {
 			push(@exists, $page);
 		}
 	}
-
 	if (@exists > 0) {
-
 		return &plugin_rename_phase1('already', \@exists);
 	} else {
 		%pages = ();
@@ -249,14 +197,10 @@ sub plugin_rename_regex {
 		return &plugin_rename_phase3(%pages);
 	}
 }
-
 sub plugin_rename_phase3 {
 	my(%pages) = @_;
-
 	my $msg = my $input = '';
 	my %files = &plugin_rename_get_files(%pages);
-
-
 	%exists = ();
 	foreach $_page (keys %files) {
 		my $arr = $files{$_page};
@@ -267,12 +211,10 @@ sub plugin_rename_phase3 {
 			}
 		}
 	}
-
 	$pass = &plugin_rename_getvar('mypassword');
 	if (&plugin_rename_getvar('exec') eq 1) {
 		return &plugin_rename_proceed(\%pages, \%files, \%exists);
 	}
-
 	$method = &plugin_rename_getvar('method');
 	if ($method eq 'regex') {
 		$s_src = &htmlspecialchars(&plugin_rename_getvar('src'));
@@ -291,12 +233,10 @@ sub plugin_rename_phase3 {
 		$input .= '<input type="hidden" name="page"    value="' . $s_page    . '" />';
 		$input .= '<input type="hidden" name="related" value="' . $s_related . '" />';
 	}
-
 	if ((keys %exists) >0) {
 		$msg .= $::resource{'rename_plugin_err_already_below'} . '<ul>';
 		foreach $page (keys %exists) {
 			my $arr = $exists{$page};
-
 			$msg .= '<li>' . &make_pagelink(&dbmname_decode($page));
 			$msg .= $::resource{'rename_plugin_msg_arrow'};
 			$msg .= &htmlspecialchars(&dbmname_decode($pages{$page}));
@@ -312,16 +252,13 @@ sub plugin_rename_phase3 {
 			$msg .= '</li>' . "\n";
 		}
 		$msg .= '</ul><hr />' . "\n";
-
 		$input .= '<input type="radio" name="exist" value="0" checked="checked" />' .
 			$::resource{'rename_plugin_msg_exist_none'} . '<br />';
 		$input .= '<input type="radio" name="exist" value="1" />' .
 			$::resource{'rename_plugin_msg_exist_overwrite'} . '<br />';
 	}
-
 	%ret = ();
 	$ret{'msg'} = "\t$::resource{'rename_plugin_msg_title'}";
-
 	$ret{'body'} = <<EOD;
 <p>$msg</p>
 <table><tr><td>
@@ -333,14 +270,12 @@ sub plugin_rename_phase3 {
   <input type="hidden" name="cmd" value="rename" />
   <input type="hidden" name="exec" value="1" />
   $input
-  <input type="submit" value="@{[$::resource{'rename_plugin_btn_submit'}]}" />
+  <input type="submit" value="$::resource{'rename_plugin_btn_submit'}" />
  </div>
 </form>
+</td></tr>
 </table>
 EOD
-#  @{[$::resource{'rename_plugin_msg_adminpass'}]}
-#  <input type="password" name="mypassword" value="" />
-
 	$ret{'body'} .= '<ul>' . "\n";
 	foreach $old (reverse sort keys %pages) {
 		$new = $pages{$old};
@@ -351,95 +286,61 @@ EOD
 	$ret{'body'} .= '</ul>' . "\n";
 	return %ret;
 }
-
-
-# оݤΥեξʸեѥեѥˤΰ
 sub plugin_rename_get_files {
 	my (%pages) = @_;
-
 	my %files = ();
-	@dirs  = ($::diff_dir, $::data_dir);
+	@dirs  = ($::diff_dir, $::data_dir, $::counter_dir, $::info_dir);#compact
+	@dirs  = ($::diff_dir, $::data_dir, $::counter_dir, $::info_dir, $::backup_dir);#nocompact
 	if (&exist_plugin('attach')){
 		push (@dirs, $::upload_dir);
 	}
 	if (&exist_plugin('rename')) {
 		push (@dirs, $::rename_dir);
 	}
-
-
 	foreach $path (@dirs) {
 		opendir(DH,$path);
 		if (! DH){
 			next;
 		}
-
-
 		if($path=~/.*[^\/]$/) {
 			$path .= '/';
 		}
-
 		while ($file = readdir(DH)) {
 			if ($file eq '.' || $file eq '..'){
 				next;
 			}
-			
 			foreach $from (keys %pages) {
-
 				$to = $pages{$from};
-
-
-				if($path=~/$::rename_dir/) {
-					$from = &encode(&dbmname_decode($from));
-					$to = &encode(&dbmname_decode($to));
-				}
-
-
 				$from=~s/\//\\\//g;
-
-
 				my $pattern = '^' . $from . '([._].+)$';
 				if (not $file=~/$pattern/) {
 					next;
 				}
-
 				$newfile = $to . $1;
 				$files{$from}{$path . $file} = $path . $newfile;
 			}
 		}
 	}
-
 	return %files;
 }
-
-# 
 sub plugin_rename_proceed {
 	my ($pages, $files, $exists) = @_;
-
-
 	if (&plugin_rename_getvar('exist') ne '1') {
-
 		foreach my $key (keys %$exists) {
 			my $arr = $exists->{$key};
 			delete $files->{$key};
 		}
 	}
-
 	foreach $page(keys %$files) {
 		$arr = $files->{$page};
-
 		foreach $old (keys %$arr) {
 			$new = $arr->{$old};
-
-
 			if (exists($exists->{$page}{$old}) && defined($exists->{$page}{$old})){
 				unlink($new);
 			}
 			rename($old, $new);
-
 		}
 	}
-
-
 	$postdata = $::database{PLUGIN_RENAME_LOGPAGE};
 	$postdata .= '*' . &date($::date_format . " " . $::time_format . " (D)") . "\n";
 	if (&plugin_rename_getvar('method') eq 'regex') {
@@ -451,7 +352,6 @@ sub plugin_rename_proceed {
 		$postdata .= '--From:[[' . &plugin_rename_getvar('refer') . ']]' . "\n";
 		$postdata .= '--To:[['   . &plugin_rename_getvar('page')  . ']]' . "\n";
 	}
-
 	if ((keys %$exists) > 0) {
 		$postdata .= "\n" . $::resource{'rename_plugin_msg_result'} . "\n";
 		foreach  $page (keys %$exists) {
@@ -466,41 +366,28 @@ sub plugin_rename_proceed {
 		}
 		$postdata .= '----' . "\n";
 	}
-
 	foreach $old (keys %$pages) {
 		$new = $pages->{$old};
 		$postdata .= '-' . &dbmname_decode($old) .
 			$::resource{'rename_plugin_msg_arrow'} . &dbmname_decode($new) . "\n";
 	}
-
-
-
-
-
 	$::database{::PLUGIN_RENAME_LOGPAGE} = $postdata;
 	&close_db();
-
-
 	$page = &plugin_rename_getvar('page');
 	if ($page eq '') {
 		$page = PLUGIN_RENAME_LOGPAGE;
 	}
-
 	print &http_header(
 		"Status: 302",
 		"Location: $::basehref?@{[&encode($page)]}"
 		);
 }
-
 sub plugin_rename_getrelated {
 	my ($page) = @_;
-
 	@related = ();
 	@pages = keys %::database;
-
 	($striped_page = &strip_bracket($page))=~s/\//\\\//g;
 	$pattern = '(?:^|\/)' . $striped_page . '(?:\/|$)';
-
 	foreach  $name (@pages) {
 		if ($name eq $page) {
 			next;
@@ -509,91 +396,52 @@ sub plugin_rename_getrelated {
 			push(@related, $name);
 		}
 	}
-
 	return @related;
 }
-
-
-# ¸ߤڡ٤ƤΥץ
 sub plugin_rename_getselecttag {
 	my ($page) = @_;
-
 	my %pages = ();
 	foreach $_page (sort keys %::database) {
-
 		$selected = ($_page eq $page) ? ' selected' : '';
 		$s_page = &htmlspecialchars($_page);
 		$pages{$_page} = '<option value="' . $s_page . '"' . $selected . '>' .
 			$s_page . '</option>';
-
 	}
-
 	my @pages = sort values %pages;
-
 	$list = join("\n ", @pages);
-
 	return <<EOD;
 <select name="refer">
  <option value=""></option>
  $list
 </select>
 EOD
-
 }
-
-# ڡ̾Υǥɡ<==> dbmname
 sub dbmname_decode {
 	my $name = shift;
 	return ($name =~/^[0-9a-f]+$/i) ? pack('H*', $name ) : $name ;
 }
-
-# [[ ]] 
-# from PukiWiki lib/func.php
 sub strip_bracket {
 	my ($str) = @_;
-
 	if ($str=~/^\[\[(.*)\]\]$/) {
 		return $1;
 	} else {
 		return $str;
 	}
 }
-
-# from PukiWiki lib/make_link.php
-# ʬǤ
 sub make_pagelink {
 	my $page = shift;
 	return qq|<a href="$::script?@{[&encode($page)]}">$page</a>|;
 }
-
-# ڡ̾Ȥɤå
-# from PukiWiki lib/func.php
 sub is_pagename {
 	my ($str) = @_;
 	my $is_pagename= (not &is_interwiki($str) &&
 						$str=~/^(?!\/)$bracket_name$(?<!\/$)/ &&
 						$str=~/(^|\/)\.{1,2}(\/|$)/);
-
 	return $is_pagename;
 }
-
-# from PukiWiki lib/func.php
 sub is_interwiki {
 	my ($str) = @_;
-
-
-
-
-
-
-
-
-
-
 	return $str=~/^$interwiki_name$/;
 }
-
-
 1;
 __END__
-
